@@ -5,15 +5,15 @@ from voluptuous import UNDEFINED
 class ItemBase():
     pass
 
-class NodeBase(ABC, ItemBase):
+class NodeBase(ItemBase):
 
-    @abstractmethod
     def serialize(self):
         """Serialize the class
 
         Returns:
             any type of primitive types eg int, list, dict, str...
         """
+        return self.__dict__
 
 class LeafBase(ABC, ItemBase):
 
